<ul class="nav nav-tabs" id="myTab" role="tablist">
    {% for item in container_items %}
        <li class="nav-item" role="presentation">
        <button class="nav-link {% if loop.first %}active{% endif %}" id="{{ col }}-{{ item.id }}-tab" data-bs-toggle="tab" data-bs-target="#{{ col }}-{{ item.id }}" type="button" role="tab" aria-controls="{{ col }}-{{ item.id }}" aria-selected="{% if loop.first %}true{% else %}false{% endif %}">{{ item.name }}</button>
        </li>
    {% endfor %}
</ul>
<div class="tab-content" id="myTabContent">
    {% for item in container_items %}
        <div class="tab-pane fade {% if loop.first %}show active{% endif %}" id="{{ col }}-{{ item.id }}" role="tabpanel" aria-labelledby="{{ col }}-{{ item.id }}-tab">
            {{ item.render() }}
        </div>
    {% endfor %}
</div>
