<select class="form-select" aria-label="Select Columns" id="variables-dropdown">
  <option selected value="">All Columns</option>
  {% for item in dropdown_items %}
      <option value="{{item}}">{{item}}</option>
  {% endfor %}
</select>

{{ dropdown_content.render()}}