<div class="col-sm-12 text-right">
    <button class="btn btn-sm"
            data-bs-toggle="collapse"
            data-bs-target="#bottom-{{ id }}, #minifreqtable{{ id }}"
            aria-expanded="false"
            aria-controls="collapseExample">
        {{ text }}
    </button>
</div>