{% if type == 'small' %}
    <img class="img-responsive center-img" src="{{ plot }}", style="width:90%; height:auto">
{% elif type == 'categorical' %}
    <img class="img-responsive center-img" src="{{ plot }}", style="width:auto; height:70%">
{% else %}
<div class="text-center py-3">
    <img class="img-fluid mx-auto d-block" src="{{ plot }}", style="width:100%; height: auto">
</div>
{% endif %}