<div class="variable container">
    <div class="row" style="padding-bottom: 20px;"> 
        <h1 class="h5 text-primary"  title="{{name}}">{{ name }}</h1>
        <p class="lead" title="{{name}}">{{ type }}</p>
    </div>
    <div class="row">
        {% for key, value in content.items() %}
            <div class="col">
                {{ value.render() }}
            </div>
        {% endfor %}
    </div>
    {% if bottom is not none %}
        {{ bottom.render() }}
    {% endif %}
</div>