{% if not id %}
    {% if name %}
    <p class="h5">{{ name }}</p>
    {% endif %}

    <table class="table table-sm">
    {% for key, value in data.items() %}
        <tr>
            <th>{{ key }}</th>
            <td>{{ value }}</td>
        </tr>
    {% endfor %}
    </table>
{% else %}
    <div class="table-overflow">
        {{ data|safe }}
    </div>
{% endif %}
