<nav class="navbar navbar-expand-lg bg-body-tertiary">
    <div class="container-fluid">
        {% for nav_item in nav_items %}
           <span class="navbar-brand" style="color: rgb (111,111,111);">{{ nav_item }}</span> 
        {% endfor %}
    </div>
</nav>