<!doctype html>
<html lang="en">
    <head>
        {% include 'style.html' %}
    </head>
    <body>
        {% include 'navigation.html' %}
        
        {{ body.render() }}

        {% include 'script.html' %}
    </body>

</html>