<div class="section-div container">
    {% for container_item in container_items %}
        {% if container_item.name %}
            <div class="row" style="margin: 40px">
                <h3> {{ container_item.name }} </h3>
            </div>
        {% endif %}

        {{ container_item.render() }}

    {% endfor %}
</div>
