<div class="container section-div">
    <div class="section-data row">
        {% for container_item in container_items %}
            {{ container_item.render() }}
        {% endfor %}
    </div>
</div>