.section-div {
    padding-right: 15px;
    padding-left: 15px;
    margin-right: auto;
    margin-left: auto;
}

.section-data {
    border: 1px solid #e1e1e8;
    padding: 2em 2em;
    margin-right: -15px;
    margin-left: -15px;
}

.variable{
    padding: 2em 2em;
    margin-right: -15px;
    margin-left: -15px;
    border: 1px solid #e1e1e8;
    border-right: hidden;
    border-left:hidden;
}
.cont-padding{
    position: relative;
    min-height: 1px;
    padding-right: 15px;
    padding-left: 15px;
    float: left;
}

.table-overflow {
    width: 95%; /* or any specific width */
    overflow-x: auto; /* enables horizontal scrolling */
  }